========================
Django Frontend Skeleton
========================

Django Frontend Skeleton is a basic Django template skeleton built on `HTML5 Boilerplate <https://github.com/h5bp/html5-boilerplate>`_ and `Twitter Bootstrap <https://github.com/twitter/bootstrap>`_.

With the convenience of an installable Django application, create custom templates built on top of one of the most well-known, widespread templates (HTML5 Boilerplate) and a robust front-end framework (Twitter Bootstrap.)

Version 2.0.0 of Django Frontend Skeleton is a much simpler package - it's now just a small extended 'skeleton' template, which requires Django Frontend. No more duplication!

---------
Starring
---------
* `HTML5 Boilerplate (based on 4.3.0/master) <https://github.com/h5bp/html5-boilerplate>`_
* `Modernizr (2.7.1) <https://github.com/Modernizr/Modernizr>`_
* `jQuery (1.11.0) and (2.1.0) <https://github.com/jquery/jquery>`_
* `Twitter Bootstrap (3.0.3) <https://github.com/twbs/bootstrap>`_
* `iOS-Orientationchange-Fix <https://github.com/scottjehl/iOS-Orientationchange-Fix>`_

-----------------
More Information
-----------------

For more information, instructions on how to get started, and a changelog `read the documentation <https://django-frontend-skeleton.readthedocs.org/>`_.